"""Custom topology example

Two directly connected switches plus a host for each switch:

   host --- switch --- switch --- host

Adding the 'topos' dict with a key/value pair to generate our newly defined
topology enables one to pass in '--topo=mytopo' from the command line.
"""

from mininet.topo import Topo


class MyTopo(Topo):
    "Simple topology example."

    def __init__(self):
        "Create custom topo."

        # Initialize topology
        Topo.__init__(self)

        # Add hosts and switches
        leftHost = self.addHost('h1')
        rightHost = self.addHost('h2')
        leftSwitch = self.addSwitch('s3')
        rightSwitch = self.addSwitch('s4')

        # Add links
        self.addLink(leftHost, leftSwitch, bw=10, delay="1ms", loss=0)
        self.addLink(leftSwitch, rightSwitch, bw=5, delay="10ms", loss=0)
        self.addLink(rightSwitch, rightHost, bw=10, delay="1ms", loss=0)


class RE350Topo(Topo):
    def __init__(self):
        Topo.__init__(self)
        host={}
        switch={}

        # TODO: add the description of the topology here




topos = {'mytopo': (lambda: MyTopo()),
         're350': (lambda: RE350Topo())
        }
